@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::spec::transform::aggregate::AggregateOpSpec;
 use crate::spec::values::{SignalExpressionSpec, SortOrderSpec};
 use serde::{Deserialize, Serialize};
@@ -88,6 +80,9 @@ pub enum ScaleDomainSpec {
 pub struct ScaleDataReferencesSpec {
     pub fields: Vec<ScaleDataReferenceSpec>,
 
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub sort: Option<ScaleDataReferenceSort>,
+
     #[serde(flatten)]
     pub extra: HashMap<String, Value>,
 }
