@@ -1,11 +1,8 @@
-use crate::data::scalar::{ScalarValue, ScalarValueHelpers};
-use crate::data::table::VegaFusionTable;
-use crate::error::{Result, VegaFusionError};
 use crate::expression::parser::parse;
 use crate::proto::gen::tasks::data_url_task::Url;
 use crate::proto::gen::tasks::{
     scan_url_format, DataSourceTask, DataUrlTask, DataValuesTask, ParseFieldSpec, ParseFieldSpecs,
-    ScanUrlFormat, Task, TzConfig, Variable,
+    ScanUrlFormat, Task, TzConfig, Variable, VariableNamespace,
 };
 use crate::proto::gen::transforms::TransformPipeline;
 use crate::spec::chart::{ChartSpec, ChartVisitor};
@@ -20,9 +17,14 @@ use crate::spec::values::{SignalExpressionSpec, StringOrSignalSpec};
 use crate::task_graph::graph::ScopedVariable;
 use crate::task_graph::scope::TaskScope;
 use crate::task_graph::task_value::TaskValue;
+use datafusion_common::ScalarValue;
+use rand::random;
 use std::collections::{HashMap, HashSet};
 use std::convert::TryFrom;
 use std::ops::Deref;
+use vegafusion_common::data::scalar::ScalarValueHelpers;
+use vegafusion_common::data::table::VegaFusionTable;
+use vegafusion_common::error::Result;
 
 #[derive(Clone, Debug, Default)]
 pub struct MakeTaskScopeVisitor {
@@ -166,10 +168,14 @@ impl<'a> ChartVisitor for MakeTasksVisitor<'a> {
 
             // Append fingerprint to URL that references an inline dataset
             if let Url::String(url) = &proto_url {
-                if let Some(inline_name) = url.strip_prefix("vegafusion+dataset://") {
+                if let Some(inline_name) = extract_inline_dataset(url) {
                     let inline_name = inline_name.trim().to_string();
                     if let Some(fingerprint) = self.dataset_fingerprints.get(&inline_name) {
                         proto_url = Url::String(format!("{url}#{fingerprint}"));
+                    } else {
+                        // Unknown fingerprint, use random id to break cache
+                        let fingerprint = random::<u64>();
+                        proto_url = Url::String(format!("{url}#{fingerprint}"));
                     }
                 }
             }
@@ -235,9 +241,8 @@ impl<'a> ChartVisitor for MakeTasksVisitor<'a> {
             let expression = parse(update)?;
             Task::new_signal(signal_var, scope, expression, &self.tz_config)
         } else {
-            return Err(VegaFusionError::internal(format!(
-                "Signal must have an initial value or an update expression: {signal:#?}"
-            )));
+            let value = TaskValue::Scalar(ScalarValue::Null);
+            Task::new_value(signal_var, scope, value)
         };
 
         self.tasks.push(task);
@@ -336,6 +341,17 @@ impl<'a> ChartVisitor for UpdateVarsChartVisitor<'a> {
         {
             self.update_vars
                 .insert((Variable::new_signal(&signal.name), Vec::from(scope)));
+        } else {
+            // Check for empty signal that has an update in a child signal of the same name
+            // Note: We rely on the fact that visit_signal is called after child groups have been
+            // visited
+            for v in &self.update_vars {
+                if v.0.namespace == VariableNamespace::Signal as i32 && v.0.name == signal.name {
+                    self.update_vars
+                        .insert((Variable::new_signal(&signal.name), Vec::from(scope)));
+                    break;
+                }
+            }
         }
 
         // Check for signal expressions that have update dependencies
@@ -620,3 +636,11 @@ impl<'a> ChartVisitor for InputVarsChartVisitor<'a> {
         Ok(())
     }
 }
+
+pub fn extract_inline_dataset(url: &str) -> Option<String> {
+    if let Some(s) = url.strip_prefix("vegafusion+dataset://") {
+        Some(s.to_string())
+    } else {
+        url.strip_prefix("table://").map(|s| s.to_string())
+    }
+}
