@@ -1,9 +1,9 @@
-use crate::data::scalar::ScalarValue;
-use crate::data::table::VegaFusionTable;
-use arrow::array::ArrayRef;
-use arrow::datatypes::{DataType, Field, Schema};
-use arrow::record_batch::RecordBatch;
+use datafusion_common::ScalarValue;
 use std::mem::{size_of, size_of_val};
+use vegafusion_common::arrow::array::ArrayRef;
+use vegafusion_common::arrow::datatypes::{DataType, Field, Schema};
+use vegafusion_common::arrow::record_batch::RecordBatch;
+use vegafusion_common::data::table::VegaFusionTable;
 
 /// Get the size of a Field value, including any inner heap-allocated data
 fn size_of_field(field: &Field) -> usize {
